{% extends 'subscriptions/base_developer.html' %}

{% load i18n %}

{% block title %}DFS Dashboard | Delete Subscription Plan{% endblock %}

{% block main %}
  <div class="breadcrumb">
    <a href="{% url 'dfs_dashboard' %}">Developer Dashboard</a>
    > <a href="{% url 'dfs_plan_list' %}">Subscription Plans</a>
    > Delete Subscription Plan
  </div>

  <h2>Delete Subscription Plan</h2>

  <div>Are you sure you want to delete this subscription plan?</div>

  <blockquote>
    <strong>Plan name:</strong> {{ plan.plan_name }}<br>
    <strong>Plan description:</strong> {{ plan.plan_description }}
  </blockquote>

  <form method="POST">
    {% csrf_token %}
    <input class="button-negative" type="submit" value="Delete">
  </form>

  <a class="button-positive" href="{% url 'dfs_plan_list' %}">Cancel</a>
{% endblock %}
