{% extends 'subscriptions/base_developer.html' %}

{% load i18n %}

{% block title %}DFS Dashboard | Delete Plan List{% endblock %}

{% block main %}
  <div class="breadcrumb">
    <a href="{% url 'dfs_dashboard' %}">Developer Dashboard</a>
    > <a href="{% url 'dfs_plan_list_list' %}">Plans Lists</a>
    > Delete Plan List
  </div>

  <h2>Delete Plan List</h2>

  <div>Are you sure you want to delete this plan list?</div>

  <blockquote>
      <strong>Plan List:</strong> {{ plan_list.title }}
  </blockquote>


  <form method="POST">
    {% csrf_token %}
    <input class="button-negative" type="submit" value="Delete">
  </form>

  <a class="button-positive" href="{% url 'dfs_plan_list_list' %}">Cancel</a>
{% endblock %}
