# Generated by Django 3.0.3 on 2020-02-17 01:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('subscriptions', '0005_update_recurrence_unit_default'),
    ]

    operations = [
        migrations.AddField(
            model_name='plancost',
            name='slug',
            field=models.SlugField(
                blank=True,
                help_text='slug to reference these cost details',
                max_length=128,
                null=True,
                unique=True,
            ),
        ),
        migrations.AddField(
            model_name='subscriptionplan',
            name='slug',
            field=models.SlugField(
                blank=True,
                help_text='slug to reference the subscription plan',
                max_length=128,
                null=True,
                unique=True,
            ),
        ),
        migrations.AddField(
            model_name='planlist',
            name='slug',
            field=models.SlugField(
                blank=True,
                help_text='slug to reference the subscription plan list',
                max_length=128,
                null=True,
                unique=True,
            ),
        ),
    ]
