{% if is_paginated %}
  <div class="pagination">
    {% if page_obj.has_previous %}
      <a href="?page=1">&laquo; first</a> |
      <a href="?page={{ page_obj.previous_page_number }}">previous</a> |
    {% endif %}

    <strong>
      Page {{ page_obj.number }} of {{ page_obj.paginator.num_pages }}
    </strong>

    {% if page_obj.has_next %}
      | <a href="?page={{ page_obj.next_page_number }}">next</a>
      | <a href="?page={{ page_obj.paginator.num_pages }}">last &raquo;</a>
    {% endif %}
  </div>
{% endif %}
