{% extends 'subscriptions/base_developer.html' %}

{% load i18n %}

{% block title %}DFS Dashboard | Delete User Subscription{% endblock %}

{% block main %}
  <div class="breadcrumb">
    <a href="{% url 'dfs_dashboard' %}">Developer Dashboard</a>
    > <a href="{% url 'dfs_subscription_list' %}">User Subscriptions</a>
    > Delete User Subscription
  </div>

  <h2>Delete User Subscription</h2>

  <div>Are you sure you want to delete this user subscription?</div>

  <blockquote>
    <strong>User:</strong> {{ subscription.user }}<br>
    <strong>Plan:</strong> {{ subscription.plan }}<br>
    <strong>Billing start date:</strong> {{ subscription.date_billing_start }}<br>
    <strong>Billing end date:</strong> {{ subscription.date_billing_end }}<br>
    <strong>Last billing date:</strong> {{ subscription.date_billing_last }}<br>
    <strong>Next billing date:</strong> {{ subscription.date_billing_next }}<br>
    <strong>Active?:</strong> {{ subscription.active }}<br>
    <strong>Cancelled?:</strong> {{ subscription.cancelled }}
  </blockquote>

  <form method="POST">
    {% csrf_token %}
    <input class="button-negative" type="submit" value="Delete">
  </form>

  <a class="button-positive" href="{% url 'dfs_subscription_list' %}">Cancel</a>
{% endblock %}
