"""Application configuration file for django-flexible-subscriptions."""
from django.apps import AppConfig


class FlexibleSubscriptionsConfig(AppConfig):
    """Configuration details for django-flexible-subscriptions."""
    name = 'subscriptions'
    verbose_name = 'django-flexible-subscriptions'
